# automatically generated by the FlatBuffers compiler, do not modify

# namespace: spacy

import flatbuffers

class NERSpacyResponse(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAsNERSpacyResponse(cls, buf, offset):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = NERSpacyResponse()
        x.Init(buf, n + offset)
        return x

    # NERSpacyResponse
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # NERSpacyResponse
    def Text(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # NERSpacyResponse
    def StartChar(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int32Flags, o + self._tab.Pos)
        return 0

    # NERSpacyResponse
    def EndChar(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int32Flags, o + self._tab.Pos)
        return 0

    # NERSpacyResponse
    def Label(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

def NERSpacyResponseStart(builder): builder.StartObject(4)
def NERSpacyResponseAddText(builder, text): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(text), 0)
def NERSpacyResponseAddStartChar(builder, startChar): builder.PrependInt32Slot(1, startChar, 0)
def NERSpacyResponseAddEndChar(builder, endChar): builder.PrependInt32Slot(2, endChar, 0)
def NERSpacyResponseAddLabel(builder, label): builder.PrependUOffsetTRelativeSlot(3, flatbuffers.number_types.UOffsetTFlags.py_type(label), 0)
def NERSpacyResponseEnd(builder): return builder.EndObject()



# automatically generated by the FlatBuffers compiler, do not modify

# namespace: spacy

import flatbuffers

class SpacyRequest(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAsSpacyRequest(cls, buf, offset):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = SpacyRequest()
        x.Init(buf, n + offset)
        return x

    # SpacyRequest
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # SpacyRequest
    def Text(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # SpacyRequest
    def Type(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            a = self._tab.Vector(o)
            return self._tab.Get(flatbuffers.number_types.Int8Flags, a + flatbuffers.number_types.UOffsetTFlags.py_type(j * 1))
        return 0

    # SpacyRequest
    def TypeAsNumpy(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.GetVectorAsNumpy(flatbuffers.number_types.Int8Flags, o)
        return 0

    # SpacyRequest
    def TypeLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

def SpacyRequestStart(builder): builder.StartObject(2)
def SpacyRequestAddText(builder, text): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(text), 0)
def SpacyRequestAddType(builder, type): builder.PrependUOffsetTRelativeSlot(1, flatbuffers.number_types.UOffsetTFlags.py_type(type), 0)
def SpacyRequestStartTypeVector(builder, numElems): return builder.StartVector(1, numElems, 1)
def SpacyRequestEnd(builder): return builder.EndObject()



# automatically generated by the FlatBuffers compiler, do not modify

# namespace: spacy

import flatbuffers

class SpacyResponse(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAsSpacyResponse(cls, buf, offset):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = SpacyResponse()
        x.Init(buf, n + offset)
        return x

    # SpacyResponse
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # SpacyResponse
    def Dep(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            x = self._tab.Vector(o)
            x += flatbuffers.number_types.UOffsetTFlags.py_type(j) * 4
            x = self._tab.Indirect(x)
            from .DEPSpacyResponse import DEPSpacyResponse
            obj = DEPSpacyResponse()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # SpacyResponse
    def DepLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # SpacyResponse
    def Ner(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            x = self._tab.Vector(o)
            x += flatbuffers.number_types.UOffsetTFlags.py_type(j) * 4
            x = self._tab.Indirect(x)
            from .NERSpacyResponse import NERSpacyResponse
            obj = NERSpacyResponse()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # SpacyResponse
    def NerLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

def SpacyResponseStart(builder): builder.StartObject(2)
def SpacyResponseAddDep(builder, dep): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(dep), 0)
def SpacyResponseStartDepVector(builder, numElems): return builder.StartVector(4, numElems, 4)
def SpacyResponseAddNer(builder, ner): builder.PrependUOffsetTRelativeSlot(1, flatbuffers.number_types.UOffsetTFlags.py_type(ner), 0)
def SpacyResponseStartNerVector(builder, numElems): return builder.StartVector(4, numElems, 4)
def SpacyResponseEnd(builder): return builder.EndObject()



from enum import IntEnum
from typing import List
from dataclasses import dataclass
import numpy as np
import flatbuffers
from keios_protocol_common import FlatbufferObject
from keios_protocol_spacy.flatbuffers import DEPSpacyResponse as DEPSpacyResponseClass
from keios_protocol_spacy.flatbuffers import NERSpacyResponse as NERSpacyResponseClass
from keios_protocol_spacy.flatbuffers import SpacyRequest as SpacyRequestClass
from keios_protocol_spacy.flatbuffers import SpacyResponse as SpacyResponseClass
from keios_protocol_spacy.flatbuffers import Type as TypeClass

@dataclass
class DEPSpacyResponseData:
    lang: str
    relation: str
    source: str
    source_pos: str
    source_index: int
    source_tag: str
    source_base: str
    target: str
    target_pos: str
    target_index: int
    target_tag: str
    target_base: str

class DEPSpacyResponseEntity(FlatbufferObject):
    def __init__(self, builder):
        super().__init__(DEPSpacyResponseData, DEPSpacyResponseClass, builder)

    def dataclass_to_flatbuffer(self, dataclass):
        str_attr_dict = {}
        for str_attr in [
            'lang',
            'relation',
            'source',
            'source_pos',
            'source_tag',
            'source_base',
            'target',
            'target_pos',
            'target_tag',
            'target_base'
        ]:
            str_attr_dict[str_attr] = self.build_string(getattr(dataclass, str_attr))
        self.start()
        # set string attributes
        self['Lang']        = str_attr_dict['lang']
        self['Relation']    = str_attr_dict['relation']
        self['Source']      = str_attr_dict['source']
        self['SourcePos']   = str_attr_dict['source_pos']
        self['SourceTag']   = str_attr_dict['source_tag']
        self['SourceBase']  = str_attr_dict['source_base']
        self['Target']      = str_attr_dict['target']
        self['TargetPos']   = str_attr_dict['target_pos']
        self['TargetTag']   = str_attr_dict['target_tag']
        self['TargetBase']  = str_attr_dict['target_base']
        # set other attributes
        self['SourceIndex'] = dataclass.source_index
        self['TargetIndex'] = dataclass.target_index
        return self.end()
        
    def flatbuffer_to_dataclass(self, flatbuffer):
        return DEPSpacyResponseData(
            lang            = self['Lang'].decode("utf-8"),
            relation        = self['Relation'].decode("utf-8"),
            source          = self['Source'].decode("utf-8"),
            source_pos      = self['SourcePos'].decode("utf-8"),
            source_index    = self['SourceIndex'],
            source_tag      = self['SourceTag'].decode("utf-8"),
            source_base     = self['SourceBase'].decode("utf-8"),
            target          = self['Target'].decode("utf-8"),
            target_pos      = self['TargetPos'].decode("utf-8"),
            target_index    = self['TargetIndex'],
            target_tag      = self['TargetTag'].decode("utf-8"),
            target_base     = self['TargetBase'].decode("utf-8")
        )

@dataclass
class NERSpacyResponseData:
    text: str
    start_char: int
    end_char: int
    label: str

class NERSpacyResponseEntity(FlatbufferObject):
    def __init__(self, builder):
        super().__init__(NERSpacyResponseData, NERSpacyResponseClass, builder)

    def dataclass_to_flatbuffer(self, dataclass):
        text = self.build_string(dataclass.text)
        label = self.build_string(dataclass.label)
        self.start()
        # set string attributes
        self['Text']      = text
        self['Label']     = label
        # set other attributes
        self['StartChar'] = dataclass.start_char
        self['EndChar']   = dataclass.end_char
        return self.end()
        
    def flatbuffer_to_dataclass(self, flatbuffer):
        return NERSpacyResponseData(
            text        = self['Text'].decode("utf-8"),
            start_char  = self['StartChar'],
            end_char    = self['EndChar'],
            label       = self['Label'].decode("utf-8")
        )

@dataclass
class SpacyResponseData:
    ner: List[NERSpacyResponseData]
    dep: List[DEPSpacyResponseData]

class SpacyResponseEntity(FlatbufferObject):
    def __init__(self):
        super().__init__(SpacyResponseData, SpacyResponseClass)
    
    def dataclass_to_flatbuffer(self, dataclass):
        dep_vector = self.build_vector('Dep', dataclass.dep, DEPSpacyResponseEntity)
        ner_vector = self.build_vector('Ner', dataclass.ner, NERSpacyResponseEntity)
        self.start()
        self['Dep'] = dep_vector
        self['Ner'] = ner_vector
        return self.end()
        
    def flatbuffer_to_dataclass(self, flatbuffer):
        ner = NERSpacyResponseEntity(self.builder)
        dep = DEPSpacyResponseEntity(self.builder)
        return SpacyResponseData(
            ner = [ner.build(g) for n in self['Ner']],
            dep = [dep.build(g) for d in self['Dep']]
        )

class TypeData(IntEnum):
    DEP = 0
    NER = 1

@dataclass
class SpacyRequestData:
    text: str
    type: List[TypeData]

class SpacyRequestEntity(FlatbufferObject):
    def __init__(self):
        super().__init__(SpacyRequestData, SpacyRequestClass)

    def dataclass_to_flatbuffer(self, dataclass):
        type_vector = self.build_vector('Type', [int(t) for t in dataclass.type])
        text = self.build_string(dataclass.text)
        self.start()
        self['Text'] = text
        self['Type'] = type_vector
        return self.end()
        
    def flatbuffer_to_dataclass(self, flatbuffer):
        return SpacyRequestData(
            text = self['Text'].decode("utf-8"),
            type = [TypeData(n) for n in self['Type']]
        )


# automatically generated by the FlatBuffers compiler, do not modify

# namespace: spacy

import flatbuffers

class DEPSpacyResponse(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAsDEPSpacyResponse(cls, buf, offset):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = DEPSpacyResponse()
        x.Init(buf, n + offset)
        return x

    # DEPSpacyResponse
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # DEPSpacyResponse
    def Lang(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # DEPSpacyResponse
    def Relation(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # DEPSpacyResponse
    def Source(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # DEPSpacyResponse
    def SourcePos(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # DEPSpacyResponse
    def SourceIndex(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(12))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int32Flags, o + self._tab.Pos)
        return 0

    # DEPSpacyResponse
    def SourceTag(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(14))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # DEPSpacyResponse
    def SourceBase(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(16))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # DEPSpacyResponse
    def Target(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(18))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # DEPSpacyResponse
    def TargetPos(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(20))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # DEPSpacyResponse
    def TargetIndex(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(22))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int32Flags, o + self._tab.Pos)
        return 0

    # DEPSpacyResponse
    def TargetTag(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(24))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # DEPSpacyResponse
    def TargetBase(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(26))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

def DEPSpacyResponseStart(builder): builder.StartObject(12)
def DEPSpacyResponseAddLang(builder, lang): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(lang), 0)
def DEPSpacyResponseAddRelation(builder, relation): builder.PrependUOffsetTRelativeSlot(1, flatbuffers.number_types.UOffsetTFlags.py_type(relation), 0)
def DEPSpacyResponseAddSource(builder, source): builder.PrependUOffsetTRelativeSlot(2, flatbuffers.number_types.UOffsetTFlags.py_type(source), 0)
def DEPSpacyResponseAddSourcePos(builder, sourcePos): builder.PrependUOffsetTRelativeSlot(3, flatbuffers.number_types.UOffsetTFlags.py_type(sourcePos), 0)
def DEPSpacyResponseAddSourceIndex(builder, sourceIndex): builder.PrependInt32Slot(4, sourceIndex, 0)
def DEPSpacyResponseAddSourceTag(builder, sourceTag): builder.PrependUOffsetTRelativeSlot(5, flatbuffers.number_types.UOffsetTFlags.py_type(sourceTag), 0)
def DEPSpacyResponseAddSourceBase(builder, sourceBase): builder.PrependUOffsetTRelativeSlot(6, flatbuffers.number_types.UOffsetTFlags.py_type(sourceBase), 0)
def DEPSpacyResponseAddTarget(builder, target): builder.PrependUOffsetTRelativeSlot(7, flatbuffers.number_types.UOffsetTFlags.py_type(target), 0)
def DEPSpacyResponseAddTargetPos(builder, targetPos): builder.PrependUOffsetTRelativeSlot(8, flatbuffers.number_types.UOffsetTFlags.py_type(targetPos), 0)
def DEPSpacyResponseAddTargetIndex(builder, targetIndex): builder.PrependInt32Slot(9, targetIndex, 0)
def DEPSpacyResponseAddTargetTag(builder, targetTag): builder.PrependUOffsetTRelativeSlot(10, flatbuffers.number_types.UOffsetTFlags.py_type(targetTag), 0)
def DEPSpacyResponseAddTargetBase(builder, targetBase): builder.PrependUOffsetTRelativeSlot(11, flatbuffers.number_types.UOffsetTFlags.py_type(targetBase), 0)
def DEPSpacyResponseEnd(builder): return builder.EndObject()



# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['keios_protocol_spacy']

package_data = \
{'': ['*'], 'keios_protocol_spacy': ['flatbuffers/*']}

install_requires = \
['flatbuffers>=1.11,<2.0',
 'keios-protocol-common>=0.1.0,<0.2.0',
 'numpy>=1.16,<2.0']

setup_kwargs = {
    'name': 'keios-protocol-spacy',
    'version': '0.1.2',
    'description': '',
    'long_description': None,
    'author': 'Leftshift One',
    'author_email': 'contact@leftshift.one',
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
